
/* 

Ringo Robot
Ringo_PreLoaded_Behaviors_Rev06_ReadBatt
Version 6.1 12/2015
----------------------------
Modified by AngoLito 05/2016
----------------------------

IMPORTANT NOTE:  THIS SKETCH REQUIRES ARDUINO IDE 1.6.5 OR LATER TO COMPILE
(Previous versions compile this sketch too large to fit into Ringo's processor)

This sketch showcases several possible Ringo behaviors.
Use these behaviors as starting points for your own work.
When reset or turned on, press one of the number keys on your
IR remote control to activate one of the behaviors. If Ringo
blinks red, then the key was not recognized. If Ringo blinks
green, then the key was recognized and a beavior has
been started.

Significant portions of this code written by
Dustin Soodak for Plum Geek LLC. Some portions
contributed by Kevin King.
Portions from other open source projects where noted.
This code is licensed under:
Creative Commons Attribution-ShareAlike 2.0 Generic (CC BY-SA 2.0)
https://creativecommons.org/licenses/by-sa/2.0/
Visit http://www.plumgeek.com for Ringo information.
Visit http://www.arduino.cc to learn about the Arduino.

-----------------------------------------------------------------------------------------------------
      `·.¸¸.·´´¯`··._.·   __Changes implemented by AngoLito in this version__  `·.¸¸.·´´¯`··._.·

  a) Behavior 1 - Drive With Remote
    * Pressing On/Off IR button (15) switch Off all led (after join with "A", "B" or "X" buttons you can Off all Leds)
    * Pressing PlumGeek IR button (16) toogle White lights On/Off (nice to drive in a dark room!)
    * Now with "Up" and "Down" keys Ringo runs until another direction key are pressed or "play" IR button (20) is pressed

  b) Behavior 8 - Maintain Heading
    * New line add that allows stop motors if you leave Behavior 8 with "menu" button when Ringo are turning

  c) Behavior 11 - Reading battery level (NEW)
  THIS NEW FUNCTION REQUIRES TO SOLDER 47KOhm ON NON MOUNTED R55; IF R55 IS NOT PRESSENT, ALWAYS READS MAXIMUM CHARGE
  R55 is located near of Ringo edge at left side of Neopìxel 2 (botton center), is easily accesible
  This new function is a simple mode to show battery level; is not accurate, but give you a valid value
  Battery measursament is called pressing PlumGeek IR  button (16)

  d) On power On show Battery level instead PlayStartChirp

  e) Changed indicator for "Menu" mode, 1 second flash pixel modified for "moving" style flash indicator

  IMPORTANT NOTE: with these changes memory is FULL!
  
  
        `·.¸¸.·´´¯`··._.· `·.¸¸.·´´¯`··._.·  enjoy  `·.¸¸.·´´¯`··._.·`·.¸¸.·´´¯`··._.· 

--------------------------------------------------------------------------------------------------------
*/

#include "RingoHardware.h"
#include "Behaviors.h"


void setup(){
  HardwareBegin();        //initialize Ringo's brain to work with his circuitry
  //PlayStartChirp();     //Play startup chirp and blink eyes _Line comment by AngoLito
  RxIRRestart(4);         //wait for 4 byte IR remote command
  IsIRDone();
  GetIRButton();
  RestartTimer();
  read_batt();            // Read battery on power On _Add by AngoLito
}


// global variables used by Color Wheel example
int redIntensity = 0;
int greenIntensity = 0;
int blueIntensity = 0;
int red;
int green;
int blue;
int presentDirection = 0;
int hue = 0;
int hueOpposite = 180;
// end global variables used by Color Wheel example

// New variables used by AngoLito modifications
byte num_pixel[] = {0,3,4,2,1};
byte i;
// end 


void loop(){
  restart:              //label to cause program to come back to here if "MENU" on remote is pressed in any example 
  byte button;

  
/* //Uncomment this block to restore original 1 second blinking rear pixel for "Menu" mode (less battery drain) _AngoLito
 
  if(GetTime()>1000){   //blink rear pixel once a second to indicate Ringo is in "Menu" mode
      SetPixelRGB(0,0,0,100);   // turn on rear tail light to BLUE
      delay(10);                // brief delay
      OffPixels();              // turn off all pixels
      RestartTimer();           // zero timer
      } 
      
*/

// COMMENT NEXT BLOCK IF UNCOMMENT PREVIOUS! _AngoLito

// Start alternative "Menu" flash indicator

    if(GetTime()>75){       //blink "moving style" leds in "Menu" mode  (nice but more battery drain)
    SetPixelRGB(num_pixel[i],0,0,200); //set pixel to blue_you can custom here colour
    if (i==2) {
      SetPixelRGB(5,0,0,200); //flahs both eyes
    }
    delay(7);
    i++;
    OffPixels();
    if (i>4) i=0;
    RestartTimer();
  }
  
//End alternative "Menu" flash indicator block

      
  //Example user code:  
  
  if(IsIRDone()){                   //wait for an IR remote control command to be received
      button = GetIRButton();       // read which button was pressed, store in "button" variable

     
      if(button){                   // if "button" is not zero...
        switch (button){            // activate a behavior based on which button was pressed

         case 1:                    // Button 1, "Drive with remote control" behavior
         RxIRRestart(4);            // restart wait for 4 byte IR remote command
         Behavior_DriveWithRemote();
         break;

         case 2:                    // Button 2, "Attack Bug" behavior
         RxIRRestart(4);            // restart wait for 4 byte IR remote command
         Behavior_AttackBug();
         break;

         case 3:                    // Button 3, "The Ringo Dance" behavior
         RxIRRestart(4);            // restart wait for 4 byte IR remote command
         Behavior_TheRingoDance();  // what it says NO EDGE DETECTION - DON'T LET RINGO JUMP OFF YOUR TABLE!
         break;

         case 4:                    // Button 4, "Spin Squeek" - Cover Ringo's eyes to activate 
         RxIRRestart(4);            // restart wait for 4 byte IR remote command
         Behavior_SpinSqueek();
         break;

         case 5:                    // Button 5, "Color Wheel" - Ringo's eyes match the color wheel when rotated 
         RxIRRestart(4);            // restart wait for 4 byte IR remote command
         Behavior_ColorWheel();     // virtual color wheel
         break;

         case 6:                    // Button 6, "Follow Light" - Ringo seeks light 
         RxIRRestart(4);            // restart wait for 4 byte IR remote command
         Behavior_FollowLight();         
         break;

         case 7:                    // Button 7, "Drive Square" - Ringo drives in a square using navigation functions
         RxIRRestart(4);            // restart wait for 4 byte IR remote command
         Behavior_DriveSquare();
         break;

         case 8:                    // Button 8, "Maintain Heading" - Rotate Ringo by hand and he'll return to start
                                    // Press User button and release to re-zero Ringo's heading
         RxIRRestart(4);            // restart wait for 4 byte IR remote command
         Behavior_MaintainHeading();
         break;

         case 9:                    // Button 9, "Follow Line" - Ringo follows 1/2" (1cm) wide black line on white posterboard
         RxIRRestart(4);            // restart wait for 4 byte IR remote command
         Behavior_FollowLine();
         break;

         case 10:
         RxIRRestart(4);            // Button 0, "Explore Example" - Autonymous explore. Ringo avoids barriers and edges/lines on surface
         ExploreExample(160,60,500);//explore at speed 150 for 60 seconds and pause for 500ms afterwards for it to come to a halt
         break;

         case 16:                   // plumGeek button 16, battery measurement. Angolito May 2016
         //RxIRRestart(4);
         read_batt();
         break;
         
         default:                   // if no match, break out and wait for a new code
         PlayNonAck();              // quick "NonAck" chirp to know a known button was received, but not understood as a valid command
         RxIRRestart(4);            //wait for 4 byte IR remote command
         SwitchMotorsToSerial();
         Serial.print("button: ");Serial.println(button);  // send button number pressed to serial window
         break;
        }
      }
    }//end if(IsIRDone())
}


